/*
 *  Copyright (C) 2003  Robert Paciorek
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#include "LEDAnimation.h"

/***********************************************************
 * Constructor
 ***********************************************************/
LEDAnimation::LEDAnimation()
	:fRunning(false)
{
}

/***********************************************************
 * Destructor
 ***********************************************************/
LEDAnimation::~LEDAnimation()
{
	NewStop();
}

/***********************************************************
 * Start
 ***********************************************************/
void
LEDAnimation::Start()
{
	// don't do anything if the thread is already running
	if (fThread >= 0)
		return;

	fRunning = true;
	fThread = ::spawn_thread(exit_loop,"RS LED thread",B_NORMAL_PRIORITY,this);
	::resume_thread(fThread);
}

/***********************************************************
 * Stop
 ***********************************************************/
void
LEDAnimation::Stop()
{

}

void
LEDAnimation::NewStop()
{
	// don't do anything if the thread doesn't run
	if (fThread < 0)
		return;

	fRunning = false;
	status_t result;
	::wait_for_thread(fThread,&result);

}

/***********************************************************
 * exit_loop
 ***********************************************************/
int32
LEDAnimation::exit_loop(void* data)
{
	BSerialPort serial;
	serial.Open("serial1");
	
	serial.SetRTS(true);
	
	LEDAnimation *light = (LEDAnimation*)data;
	
	while (light->fRunning)
	{
		if ( serial.IsCTS() ) {
			serial.SetRTS(false);
			light->fRunning = false;
			break;
		}
		sleep(2);
	}
	light->fThread = -1;
	return 0;
}